from wsgi_tracer.tracer import trace_wsgi, setup_logger, tree2list
import os

__all__ = ['setup_logger', 'pre_fork', 'pre_request']



def pre_fork(server, worker):
    logfile = logfile = os.getenv('apm_logfile', None)
    setup_logger(worker, logfile)


def pre_request(worker, req):
    trace_wsgi(worker)



from functools import reduce


def threshold_time(data, threshold):
    return [d for d in data if d['time'] > threshold]


def module_path(data, path):
    return [d for d in data if path in d['file_path']]


def not_include(data, path):
    return [d for d in data if path not in d['file_path']]


def app_only(data, worker):
    # works only for flask
    return [d for d in data if worker.wsgi.root_path in d['file_path']]


def compose(fns):
    return lambda data: reduce(lambda x, y: y(x), fns, data)



def tree2list(node, step=0, ret=[]):
    if not node:
        return ret
    if len(node['children']) > 0:
        # Recursion Implementation, Safe when children is less than max recursion limit
        for child in node['children']:
            tree2list(child, step=step+1, ret=ret)

    node['depth'] = step
    node.pop('children')
    ret.append(node)
    return ret
